.. _core_porting_guides:

***************************
Ansible Core Porting Guides
***************************

This section lists porting guides that can help you in updating playbooks, plugins and other parts of your Ansible infrastructure from one version of ``ansible-core`` to the next.

Please note that this is not a complete list. If you believe any extra information would be useful in these pages, you can edit by clicking `Edit on GitHub` on the top right, or raising an issue.

.. toctree::
   :maxdepth: 1
   :glob:

   porting_guide_core_2.12
   porting_guide_core_2.11
   porting_guide_base_2.10
